pub struct ClusterCommand { /* private fields */ }Expand description
Clusters (clusters)
Administrator only. Lists all Cinder clusters, show cluster detail, enable or disable a cluster.
Each cinder service runs on a host computer (possibly multiple services on the same host; it depends how you decide to deploy cinder). In order to support High Availability scenarios, services can be grouped into clusters where the same type of service (for example, cinder-volume) can run on different hosts so that if one host goes down the service is still available on a different host. Since there’s no point having these services sitting around doing nothing while waiting for some other host to go down (which is also known as Active/Passive mode), grouping services into clusters also allows cinder to support Active/Active mode in which all services in a cluster are doing work all the time.
Note: Currently the only service that can be grouped into clusters is cinder-volume.
Clusters are determined by the deployment configuration; that’s why there is no ‘create-cluster’ API call listed below. Once your services are up and running, however, you can use the following API requests to get information about your clusters and to update their status.
Implementations
Sourceimpl ClusterCommand
impl ClusterCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
session: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, session: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action