pub struct SnapshotManageCommand { /* private fields */ }Expand description
Instruct Cinder to manage a storage snapshot object.
Manages an existing backend storage snapshot object (e.g. a Linux logical volume or a SAN disk) by creating the Cinder objects required to manage it, and possibly renaming the backend storage snapshot object (driver dependent).
From an API perspective, this operation behaves very much like a snapshot creation operation.
Required HTTP Body:
{
"snapshot":
{
"volume_id": "<Cinder volume already exists in volume backend>",
"ref":
"<Driver-specific reference to the existing storage object>"
}
}See the appropriate Cinder drivers’ implementations of the manage_snapshot method to find out the accepted format of ‘ref’. For example,in LVM driver, it will be the logic volume name of snapshot which you want to manage.
This API call will return with an error if any of the above elements are missing from the request, or if the ‘volume_id’ element refers to a cinder volume that could not be found.
The snapshot will later enter the error state if it is discovered that ‘ref’ is bad.
Optional elements to ‘snapshot’ are:
name A name for the new snapshot.
description A description for the new snapshot.
metadata Key/value pairs to be associated with the new snapshot.Implementations
Sourceimpl SnapshotManageCommand
impl SnapshotManageCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
client: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, client: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action